@@ -27,12 +27,13 @@
 #include <QAction>
 #include <QMenu>
 #include <QVBoxLayout>
+#include <QFile>
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <ksharedconfig.h>
-#include <klocalizedstring.h>
-#include <kacceleratormanager.h>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KSharedConfig>
+#include <KLocalizedString>
+#include <KAcceleratorManager>
 
 class KCheckAcceleratorsInitializer : public QObject
 {
