@@ -14,12 +14,10 @@
 #ifndef KMAINWINDOW_P_H
 #define KMAINWINDOW_P_H
 
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 #include <QPointer>
 #include <QEventLoopLocker>
 
-#define K_D(Class) Class##Private * const d = k_func()
-
 class QObject;
 class QSessionManager;
 class QTimer;
@@ -33,10 +31,10 @@ public:
     bool settingsDirty: 1;
     bool autoSaveWindowSize: 1;
     bool sizeApplied: 1;
+    bool suppressCloseEvent: 1;
     KConfigGroup autoSaveGroup;
     QTimer *settingsTimer;
     QTimer *sizeTimer;
-    QTimer *positionTimer;
     QRect defaultWindowSize;
     KHelpMenu *helpMenu;
     KMainWindow *q;
@@ -59,7 +57,6 @@ public:
     };
     void setSettingsDirty(CallCompression callCompression = NoCompressCalls);
     void setSizeDirty();
-    void setPositionDirty();
 };
 
 class KMWSessionManager : public QObject
