@@ -25,14 +25,14 @@
 #include <QMenu>
 #include <QVBoxLayout>
 
-#include <kselectaction.h>
-#include <klocalizedstring.h>
+#include <KSelectAction>
+#include <KLocalizedString>
 
 namespace KDEPrivate
 {
 
 KMenuMenuHandler::KMenuMenuHandler(KXMLGUIBuilder *builder)
-    : QObject(), m_builder(builder), m_popupMenu(nullptr), m_popupAction(nullptr), m_contextMenu(nullptr)
+    : QObject(), m_builder(builder)
 {
     m_toolbarAction = new KSelectAction(i18n("Add to Toolbar"), this);
     connect(m_toolbarAction, &QAction::triggered,
@@ -87,6 +87,7 @@ void KMenuMenuHandler::buildToolbarAction()
     }
     QStringList toolbarlist;
     const auto toolbars = window->toolBars();
+    toolbarlist.reserve(toolbars.size());
     for (KToolBar *b : toolbars) {
         toolbarlist << (b->windowTitle().isEmpty() ? b->objectName() : b->windowTitle());
     }
@@ -113,17 +114,17 @@ void KMenuMenuHandler::slotSetShortcut()
     }
 
     QDialog dialog(m_builder->widget());
-    dialog.setLayout(new QVBoxLayout);
+    auto *layout = new QVBoxLayout(&dialog);
 
     KShortcutWidget swidget(&dialog);
     swidget.setShortcut(m_popupAction->shortcuts());
-    dialog.layout()->addWidget(&swidget);
+    layout->addWidget(&swidget);
 
     QDialogButtonBox box(&dialog);
     box.setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     connect(&box, &QDialogButtonBox::accepted, &dialog, &QDialog::accept);
     connect(&box, &QDialogButtonBox::rejected, &dialog, &QDialog::reject);
-    dialog.layout()->addWidget(&box);
+    layout->addWidget(&box);
 
     KActionCollection *parentCollection = nullptr;
     if (dynamic_cast<KXMLGUIClient *>(m_builder)) {
@@ -131,6 +132,7 @@ void KMenuMenuHandler::slotSetShortcut()
         KXMLGUIFactory *factory = dynamic_cast<KXMLGUIClient *>(m_builder)->factory();
         parentCollection = findParentCollection(factory, m_popupAction);
         const auto clients = factory->clients();
+        checkCollections.reserve(clients.size());
         for (KXMLGUIClient *client : clients) {
             checkCollections += client->actionCollection();
         }
