@@ -22,10 +22,10 @@
 #include <QCoreApplication>
 #include <QStandardPaths>
 
-#include <kauthorized.h>
-#include <klocalizedstring.h>
+#include <KAuthorized>
+#include <KLocalizedString>
 
-#include <assert.h>
+#include <cassert>
 
 class KXMLGUIClientPrivate
 {
@@ -96,6 +96,7 @@ KXMLGUIClient::~KXMLGUIClient()
     }
 
     delete d->m_actionCollection;
+
     delete d;
 }
 
@@ -233,7 +234,7 @@ void KXMLGUIClient::setXMLFile(const QString &_file, bool merge, bool setXMLDoc)
                    QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, _file); // kdelibs4, KF 5.0, caller passes component name
 
         if (allFiles.isEmpty() && !compatFiles.isEmpty()) {
-            qCWarning(DEBUG_KXMLGUI) << "KXMLGUI file found at deprecated location" << compatFiles << "-- please use ${KXMLGUI_INSTALL_DIR} to install this file instead.";
+            qCWarning(DEBUG_KXMLGUI) << "KXMLGUI file found at deprecated location" << compatFiles << "-- please use ${KDE_INSTALL_KXMLGUI5DIR} to install this file instead.";
         }
         allFiles += compatFiles;
     }
