@@ -1,26 +1,15 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2000 Simon Hausmann <hausmann@kde.org>
-   Copyright (C) 2000 Kurt Granroth <granroth@kde.org>
-   Copyright     2007 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 2000 Kurt Granroth <granroth@kde.org>
+    SPDX-FileCopyrightText: 2007 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kxmlguiversionhandler_p.h"
 
+#include "kxmlguiclient.h"
 #include "kxmlguifactory.h"
 
 #include <QFile>
@@ -46,12 +35,24 @@ static QList<QDomElement> extractToolBars(const QDomDocument &doc)
     return toolbars;
 }
 
-static void removeAllToolBars(QDomDocument &doc)
+static QStringList toolBarNames(const QList<QDomElement> &toolBars)
+{
+    QStringList names;
+    names.reserve(toolBars.count());
+    for (const QDomElement &e : toolBars) {
+        names.append(e.attribute(QStringLiteral("name")));
+    }
+    return names;
+}
+
+static void removeToolBars(QDomDocument &doc, const QStringList &toolBarNames)
 {
     QDomElement parent = doc.documentElement();
     const QList<QDomElement> toolBars = extractToolBars(doc);
-    Q_FOREACH (const QDomElement &e, toolBars) {
-        parent.removeChild(e);
+    for (const QDomElement &e : toolBars) {
+        if (toolBarNames.contains(e.attribute(QStringLiteral("name")))) {
+            parent.removeChild(e);
+        }
     }
 }
 
@@ -63,7 +64,7 @@ static void insertToolBars(QDomDocument &doc, const QList<QDomElement> &toolBars
     if (menuBar.isNull()) {
         insertAfter = parent.firstChildElement();    // if null, insertAfter will do an append
     }
-    Q_FOREACH (const QDomElement &e, toolBars) {
+    for (const QDomElement &e : toolBars) {
         QDomNode result = parent.insertAfter(e, insertAfter);
         Q_ASSERT(!result.isNull());
     }
@@ -169,80 +170,6 @@ static void storeActionProperties(QDomDocument &doc,
     }
 }
 
-QString KXmlGuiVersionHandler::findVersionNumber(const QString &xml)
-{
-    enum { ST_START, ST_AFTER_OPEN, ST_AFTER_GUI,
-           ST_EXPECT_VERSION, ST_VERSION_NUM
-         } state = ST_START;
-    const int length = xml.length();
-    for (int pos = 0; pos < length; pos++) {
-        switch (state) {
-        case ST_START:
-            if (xml[pos] == QLatin1Char('<')) {
-                state = ST_AFTER_OPEN;
-            }
-            break;
-        case ST_AFTER_OPEN: {
-            //Jump to gui..
-            const int guipos = xml.indexOf(QLatin1String("gui"), pos, Qt::CaseInsensitive);
-            if (guipos == -1) {
-                return QString();    //Reject
-            }
-
-            pos = guipos + 2; //Position at i, so we're moved ahead to the next character by the ++;
-            state = ST_AFTER_GUI;
-            break;
-        }
-        case ST_AFTER_GUI:
-            state = ST_EXPECT_VERSION;
-            break;
-        case ST_EXPECT_VERSION: {
-            const int verpos = xml.indexOf(QLatin1String("version"), pos, Qt::CaseInsensitive);
-            if (verpos == -1) {
-                return QString();    //Reject
-            }
-            pos = verpos + 7; // strlen("version") is 7
-            while (xml.at(pos).isSpace()) {
-                ++pos;
-            }
-            if (xml.at(pos++) != QLatin1Char('=')) {
-                return QString();    //Reject
-            }
-            while (xml.at(pos).isSpace()) {
-                ++pos;
-            }
-
-            state = ST_VERSION_NUM;
-            break;
-        }
-        case ST_VERSION_NUM: {
-            int endpos;
-            for (endpos = pos; endpos < length; endpos++) {
-                const ushort ch = xml[endpos].unicode();
-                if (ch >= QLatin1Char('0') && ch <= QLatin1Char('9')) {
-                    continue;    //Number..
-                }
-                if (ch == QLatin1Char('"')) { //End of parameter
-                    break;
-                } else { //This shouldn't be here..
-                    endpos = length;
-                }
-            }
-
-            if (endpos != pos && endpos < length) {
-                const QString matchCandidate = xml.mid(pos, endpos - pos); //Don't include " ".
-                return matchCandidate;
-            }
-
-            state = ST_EXPECT_VERSION; //Try to match a well-formed version..
-            break;
-        } //case..
-        } //switch
-    } //for
-
-    return QString();
-}
-
 KXmlGuiVersionHandler::KXmlGuiVersionHandler(const QStringList &files)
 {
     Q_ASSERT(!files.isEmpty());
@@ -255,8 +182,9 @@ KXmlGuiVersionHandler::KXmlGuiVersionHandler(const QStringList &files)
     }
 
     QList<DocStruct> allDocuments;
+    allDocuments.reserve(files.size());
 
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : files) {
         DocStruct d;
         d.file = file;
         d.data = KXMLGUIFactory::readConfigFile(file);
@@ -269,7 +197,7 @@ KXmlGuiVersionHandler::KXmlGuiVersionHandler(const QStringList &files)
     QList<DocStruct>::iterator docIt = allDocuments.begin();
     const QList<DocStruct>::iterator docEnd = allDocuments.end();
     for (; docIt != docEnd; ++docIt) {
-        const QString versionStr = findVersionNumber((*docIt).data);
+        const QString versionStr = KXMLGUIClient::findVersionNumber((*docIt).data);
         if (versionStr.isEmpty()) {
             //qCDebug(DEBUG_KXMLGUI) << "found no version in" << (*docIt).file;
             continue;
@@ -316,8 +244,9 @@ KXmlGuiVersionHandler::KXmlGuiVersionHandler(const QStringList &files)
                     // and store the properties in there
                     storeActionProperties(document, properties);
                     if (!toolbars.isEmpty()) {
-                        // remove application toolbars
-                        removeAllToolBars(document);
+                        // remove application toolbars present in the user file
+                        // (not others, that the app might have added since)
+                        removeToolBars(document, toolBarNames(toolbars));
                         // add user toolbars
                         insertToolBars(document, toolbars);
                     }
